@@ -1,5 +1,5 @@
 package PAUSE::Permissions;
-$PAUSE::Permissions::VERSION = '0.08';
+$PAUSE::Permissions::VERSION = '0.09';
 use strict;
 use warnings;
 
@@ -11,6 +11,7 @@ use File::HomeDir;
 use File::Spec::Functions 'catfile';
 use HTTP::Date qw(time2str);
 use HTTP::Tiny;
+use Carp;
 
 my $DISTNAME = 'PAUSE-Permissions';
 my $BASENAME = '06perms.txt';
@@ -155,7 +156,7 @@ PAUSE::Permissions - interface to PAUSE's module permissions file (06perms.txt)
 
 =head1 SYNOPSIS
 
-  use PAUSE::Permissions;
+  use PAUSE::Permissions 0.08;
   
   my $pp = PAUSE::Permissions->new;
   my $mp = $pp->module_permissions('HTTP::Client');
@@ -194,6 +195,9 @@ you can then call the C<module_permissions> method
 to get the permissions for a particular module.
 The SYNOPSIS gives the basic usage.
 
+B<Note>: you should make sure you're using version 0.08 or later.
+PAUSE now treats package names case insensitively with respect to
+permissions, so this module does now as well.
 
 =head1 METHODS
 
